@@ -18,6 +18,8 @@ DEFAULT_WRAPPER_STATUS = False
 DEFAULT_ERROR_STATUS = False
 DEFAULT_TEST_STATUS = False
 
+DEFAULT_LOGS_WITH_COLORS = False
+
 APPLICATION = 'application'
 
 IGNORE_MODULE_LIST = []
@@ -97,6 +99,7 @@ class Globals:
         wrapperStatus = DEFAULT_WRAPPER_STATUS,
         errorStatus = DEFAULT_ERROR_STATUS,
         testStatus = DEFAULT_TEST_STATUS,
+        logsWithColors = DEFAULT_LOGS_WITH_COLORS,
         encoding = c.ENCODING,
         printRootPathStatus = False,
         globalsEverything = False
@@ -104,6 +107,8 @@ class Globals:
 
         if globalsInstanceIsNone() :
 
+            self.logsWithColors = EnvironmentHelper.update(log.ENABLE_LOGS_WITH_COLORS, logsWithColors or log.colorsEnabled(), default=DEFAULT_LOGS_WITH_COLORS)
+
             self.logStatus = EnvironmentHelper.update(log.LOG, logStatus, default=DEFAULT_LOG_STATUS)
             self.infoStatus = EnvironmentHelper.update(log.INFO, infoStatus, default=DEFAULT_INFO_STATUS)
             self.statusStatus = EnvironmentHelper.update(log.STATUS, statusStatus, default=DEFAULT_STATUS_STATUS)
